
1.2.4 (2018-09-28)
###################

Changes since 1.2.3 (2018-09-04).

Bug Fixes
$$$$$$$$$$

* Closes `#525 <https://github.com/biocommons/hgvs/issues/525/>`_: fix c_to_p bug with insertion of in-phase Ter (credit: @ianfab) [`d40a71a6548b <https://github.com/biocommons/hgvs/commit/d40a71a6548b>`_]
* backported test for `#525 <https://github.com/biocommons/hgvs/issues/525/>`_ to 1.2 branch [`cb769e9591d5 <https://github.com/biocommons/hgvs/commit/cb769e9591d5>`_]

Other Changes
$$$$$$$$$$$$$$

* added missing changelog files for 1.2.3 [`5d2cf1c <https://github.com/biocommons/hgvs/commit/5d2cf1c>`_]
